**Example 1: 删除Notebook生命周期脚本**



Input: 

```
tccli tione DeleteNotebookLifecycleScript --cli-unfold-argument  \
    --NotebookLifecycleScriptsName abc
```

Output: 
```
{
    "Response": {
        "RequestId": "d1bf5910-d5c8-443d-80f1-15fd8adce51e"
    }
}
```

